"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.sourceNodes = exports.onPreInit = void 0;
const dynamodb_1 = __importDefault(require("aws-sdk/clients/dynamodb"));
const error_utils_1 = require("./error-utils");
const utils_1 = require("./utils");
const onPreInit = async ({ reporter }) => {
    if (reporter.setErrorMap) {
        reporter.setErrorMap(error_utils_1.ERROR_MAP);
    }
};
exports.onPreInit = onPreInit;
const sourceNodes = ({ actions, createNodeId, createContentDigest }, options) => {
    return new Promise((resolve, reject) => {
        const { createNode } = actions;
        delete options.plugins;
        const onScan = (err, data) => {
            if (err) {
                console.error("Unable to query. Error:", JSON.stringify(err, null, 2));
                reject(err);
            }
            else {
                console.log("Query succeeded.");
                data.Items.forEach((item) => {
                    const nodeData = utils_1.processData(item, createNodeId, createContentDigest, options);
                    createNode(nodeData);
                });
                if (typeof data.LastEvaluatedKey != "undefined") {
                    console.log("Scanning for more...");
                    options.params.ExclusiveStartKey = data.LastEvaluatedKey;
                    docClient.scan(options.params, onScan);
                }
                else {
                    resolve();
                }
            }
        };
        const docClient = new dynamodb_1.default.DocumentClient({
            region: options.region,
            accessKeyId: options.accessKeyId,
            secretAccessKey: options.secretAccessKey,
        });
        docClient.scan(options.params, onScan);
    });
};
exports.sourceNodes = sourceNodes;
//# sourceMappingURL=gatsby-node.js.map